@@ -1,18 +1,20 @@
 #define QT_FEATURE_accessibility_atspi_bridge 1
 
+#define QT_FEATURE_emojisegmenter 1
+
 #define QT_FEATURE_freetype 1
 
 #define QT_FEATURE_fontconfig 1
 
 #define QT_FEATURE_harfbuzz 1
 
-#define QT_FEATURE_opengles2 -1
+#define QT_FEATURE_opengles2 1
 
-#define QT_FEATURE_opengles3 -1
+#define QT_FEATURE_opengles3 1
 
-#define QT_FEATURE_opengles31 -1
+#define QT_FEATURE_opengles31 1
 
-#define QT_FEATURE_opengles32 -1
+#define QT_FEATURE_opengles32 1
 
 #define QT_FEATURE_dynamicgl -1
 
@@ -30,15 +32,15 @@
 
 #define QT_FEATURE_sessionmanager 1
 
-#define QT_FEATURE_xcb 1
+#define QT_FEATURE_xcb -1
 
-#define QT_FEATURE_xcb_glx_plugin 1
+#define QT_FEATURE_xcb_glx_plugin -1
 
 #define QT_FEATURE_texthtmlparser 1
 
 #define QT_FEATURE_textmarkdownreader 1
 
-#define QT_FEATURE_system_textmarkdownreader 1
+#define QT_FEATURE_system_textmarkdownreader -1
 
 #define QT_FEATURE_textmarkdownwriter 1
 
